@@ -49,16 +49,22 @@ get_bibentry <- function(
   toc <- toc[! duplicated(toc), ]
 
   urldate <- as.character(Sys.Date())
-
-    if (nrow(toc) == 0) {
+  
+  if (nrow(toc) == 0) {
       warning(paste0("Code ",code, "not found"))
       return()
-    }
+  }
 
-    eurostat_id <- paste0( toc$code, "_",
+  eurostat_id <- paste0( toc$code, "_",
                            gsub("\\.", "-",  toc$`last update of data`))
 
-    for ( i in 1:nrow(toc) ) {
+  for ( i in 1:nrow(toc) ) {
+
+    last_update_date  <- lubridate::dmy(toc[["last update of data"]][[i]])
+    last_update_year  <- lubridate::year(last_update_date)
+    last_update_month <- lubridate::month(last_update_date)
+    last_update_day   <- lubridate::day(last_update_date)
+
 
       if ( !is.null(keywords) ) {                             #if user entered keywords
         if ( length(keywords)<i ) {                           #last keyword not entered
@@ -75,7 +81,7 @@ get_bibentry <- function(
         title = paste0(toc$title[i]," [",code[i],"]"),
         url = paste0("https://ec.europa.eu/eurostat/web/products-datasets/-/",code[i]),
         language = "en",
-        year = paste0(toc$`last update of data`[1]),
+        year = paste0(toc$`last update of data`[i]),
         publisher = "Eurostat",
         author = "Eurostat",
         keywords = keyword_entry,
@@ -87,10 +93,9 @@ get_bibentry <- function(
       } else {
         entries <- entry
       }
-    }
+  }
 
     if (format == "bibtex") {
-
       entries <- utils::toBibtex(entries)
     } else if ( format == "biblatex") {
       entries <- RefManageR::toBiblatex ( entries )
