@@ -47,7 +47,8 @@
 #'        can not be used with a \code{filters}.
 #' @param ... further argument for \code{\link{get_eurostat_json}}.
 #' @export
-#' @author Przemyslaw Biecek, Leo Lahti, Janne Huovari and Markus Kainu \email{ropengov-forum@@googlegroups.com} \url{http://github.com/ropengov/eurostat}
+#' @references See citation("eurostat").
+#' @author Przemyslaw Biecek, Leo Lahti, Janne Huovari and Markus Kainu 
 #' @details Data sets are downloaded from 
 #' \href{http://ec.europa.eu/eurostat/estat-navtree-portlet-prod/BulkDownloadListing}{the Eurostat bulk download facility} or from The Eurostat Web Services 
 #' \href{http://ec.europa.eu/eurostat/web/json-and-unicode-web-services}{JSON API}.
@@ -114,7 +115,7 @@ get_eurostat <- function(id, time_format = "date", filters = "none",
                          select_time = NULL,
                          cache = TRUE, update_cache = FALSE, cache_dir = NULL,
                          compress_file = TRUE,
-                         stringsAsFactors = default.stringsAsFactors(),
+                         stringsAsFactors = FALSE,
                          keepFlags = FALSE, ...){
   
   # Check if you have access to ec.europe.eu. 
